@@ -24,6 +24,9 @@ CLIENT_UPDATE_DELAY = 2.0
 
 
 def get_xsan_config_dir():
+    """Gets Xsan config directory path based on the OS version
+
+    """
     config_path = ''
 
     if platform.system() == 'Darwin':
@@ -49,6 +52,13 @@ def get_xsan_config_dir():
 
 
 def update_volume_list(xsan_config_path, xsan_config_regex, config_node_regex):
+    """Parses Xsan volume config files to fetch the following data:
+        1) List of volumes on MDC
+        2) List of LUNs that each volume consists of
+
+    This data is then added to the database (models are xsan_volume and xsan_volume_lun)
+
+    """
     if os.path.isdir(xsan_config_path):
         #   flush all volume definitions first
         LOGGER.info('Flushing all volume and LUN records from DB')
@@ -103,6 +113,7 @@ def client_ping_response(client):
 
 def parse_client_io_data(client, io_data):
     """Gotta be careful here, since there should be only one stat entry for each status entry type for each host
+    Basically, this function parses client HTTP response and creates stat_entry objects in DB
 
     """
     #   Getting the cvlabel data
@@ -200,6 +211,9 @@ def parse_client_io_data(client, io_data):
 
 
 def get_stats_from_client(client):
+    """Shoots the HTTP request. Gets response body and calls parse_client_io_data
+
+    """
     io_data = None
     http_response = None
 
@@ -234,6 +248,10 @@ def get_stats_from_client(client):
 
 
 def discover_clients(xsan_config_dir):
+    """Parse config.plist
+    Get all client hostnames and IP addresses.
+
+    """
     config_plist_path = os.path.join(xsan_config_dir, 'config.plist')
     plist_data = None
 
@@ -271,6 +289,10 @@ def discover_clients(xsan_config_dir):
 
 
 def update_clients():
+    """Calls get_stats_from_clients for all client objects in database.
+    All tasks are executed in parallel.
+
+    """
     global XSAN_CONFIG_DIR
     global XSAN_VOLUME_CONFIG_REGEX
     global XSAN_CONFIG_NODE_REGEX
@@ -292,6 +314,14 @@ def update_clients():
 
 
 def main():
+    """The logic:
+
+        1) Discover our environment
+        2) Discover Xsan configuration (volumes and LUNs)
+        3) Discover clients
+        4) Grab stats from clients in an endless loop
+
+    """
     logging.basicConfig(level=LOG_LEVEL, format=LOG_FORMAT)
 
     XSAN_CONFIG_DIR = get_xsan_config_dir()
